# coding: utf-8

"""
    Stencila Hub API

    ## Authentication  Many endpoints in the Stencila Hub API require an authentication token. These tokens carry many privileges, so be sure to keep them secure. Do not place your tokens in publicly accessible areas such as client-side code. The API is only served over HTTPS to avoid exposing tokens and other data on the network.  To obtain a token, [`POST /api/tokens`](#operations-tokens-tokens_create) with either a `username` and `password` pair, or an [OpenID Connect](https://openid.net/connect/) token. Then use the token in the `Authorization` header of subsequent requests with the prefix `Token` e.g.      curl -H \"Authorization: Token 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34\" https://hub.stenci.la/api/projects/  Alternatively, you can use `Basic` authentication with the token used as the username and no password. This can be more convenient when using command line tools such as [cURL](https://curl.haxx.se/) e.g.      curl -u 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  Or, the less ubiquitous, but more accessible [httpie](https://httpie.org/):      http --auth 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  In both examples above, the trailing colon is not required but avoids being asked for a password.  ## Versioning  The Stencila Hub is released using semantic versioning. The current version is available from the [`GET /api/status`](/api/status) endpoint. Please see the [Github release page](https://github.com/stencila/hub/releases) and the [changelog](https://github.com/stencila/hub/blob/master/CHANGELOG.md) for details on each release. We currently do not provide versioning of the API but plan to do so soon (probably by using a `Accept: application/vnd.stencila.hub+json;version=1.0` request header). If you are using, or interested in using, the API please contact us and we may be able to expedite this.   # noqa: E501

    The version of the OpenAPI document: v1
    Contact: hello@stenci.la
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from stencila.hub.configuration import Configuration


class Queue(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'priority': 'int',
        'untrusted': 'bool',
        'interrupt': 'bool',
        'zone': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'priority': 'priority',
        'untrusted': 'untrusted',
        'interrupt': 'interrupt',
        'zone': 'zone'
    }

    def __init__(self, id=None, name=None, priority=None, untrusted=None, interrupt=None, zone=None, local_vars_configuration=None):  # noqa: E501
        """Queue - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._priority = None
        self._untrusted = None
        self._interrupt = None
        self._zone = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        if priority is not None:
            self.priority = priority
        if untrusted is not None:
            self.untrusted = untrusted
        if interrupt is not None:
            self.interrupt = interrupt
        self.zone = zone

    @property
    def id(self):
        """Gets the id of this Queue.  # noqa: E501


        :return: The id of this Queue.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Queue.


        :param id: The id of this Queue.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Queue.  # noqa: E501

        The name of the queue.  # noqa: E501

        :return: The name of this Queue.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Queue.

        The name of the queue.  # noqa: E501

        :param name: The name of this Queue.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 512):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `512`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def priority(self):
        """Gets the priority of this Queue.  # noqa: E501

        The relative priority of jobs placed on the queue.  # noqa: E501

        :return: The priority of this Queue.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this Queue.

        The relative priority of jobs placed on the queue.  # noqa: E501

        :param priority: The priority of this Queue.  # noqa: E501
        :type priority: int
        """

        self._priority = priority

    @property
    def untrusted(self):
        """Gets the untrusted of this Queue.  # noqa: E501

        Whether or not the queue should be sent jobs which run untrusted code.  # noqa: E501

        :return: The untrusted of this Queue.  # noqa: E501
        :rtype: bool
        """
        return self._untrusted

    @untrusted.setter
    def untrusted(self, untrusted):
        """Sets the untrusted of this Queue.

        Whether or not the queue should be sent jobs which run untrusted code.  # noqa: E501

        :param untrusted: The untrusted of this Queue.  # noqa: E501
        :type untrusted: bool
        """

        self._untrusted = untrusted

    @property
    def interrupt(self):
        """Gets the interrupt of this Queue.  # noqa: E501

        Whether or not the queue should be sent jobs which can not be interupted.False (default): jobs should not be interrupted  # noqa: E501

        :return: The interrupt of this Queue.  # noqa: E501
        :rtype: bool
        """
        return self._interrupt

    @interrupt.setter
    def interrupt(self, interrupt):
        """Sets the interrupt of this Queue.

        Whether or not the queue should be sent jobs which can not be interupted.False (default): jobs should not be interrupted  # noqa: E501

        :param interrupt: The interrupt of this Queue.  # noqa: E501
        :type interrupt: bool
        """

        self._interrupt = interrupt

    @property
    def zone(self):
        """Gets the zone of this Queue.  # noqa: E501

        The zone this job is associated with.  # noqa: E501

        :return: The zone of this Queue.  # noqa: E501
        :rtype: int
        """
        return self._zone

    @zone.setter
    def zone(self, zone):
        """Sets the zone of this Queue.

        The zone this job is associated with.  # noqa: E501

        :param zone: The zone of this Queue.  # noqa: E501
        :type zone: int
        """

        self._zone = zone

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Queue):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Queue):
            return True

        return self.to_dict() != other.to_dict()
